@@ -114,13 +114,13 @@
 #' \url{https://indrajeetpatil.github.io/ggstatsplot/articles/web_only/ggcorrmat.html}
 #'
 #' @examples
-#' 
+#'
 #' # for reproducibility
 #' set.seed(123)
-#' 
+#'
 #' # if `cor.vars` not specified, all numeric varibles used
 #' ggstatsplot::ggcorrmat(data = iris)
-#' 
+#'
 #' # to get the correlalogram
 #' # note that the function will run even if the vector with variable names is
 #' # not of same length as the number of variables
@@ -130,14 +130,14 @@
 #'   cor.vars.names = c("total sleep", "REM sleep")
 #' ) + # further modification using `ggplot2`
 #'   ggplot2::scale_y_discrete(position = "right")
-#' 
+#'
 #' # to get the correlation matrix
 #' ggstatsplot::ggcorrmat(
 #'   data = ggplot2::msleep,
 #'   cor.vars = sleep_total:bodywt,
 #'   output = "r"
 #' )
-#' 
+#'
 #' # setting output = "p-values" (or "p") will return the p-value matrix
 #' ggstatsplot::ggcorrmat(
 #'   data = ggplot2::msleep,
@@ -146,7 +146,7 @@
 #'   p.adjust.method = "bonferroni",
 #'   output = "p"
 #' )
-#' 
+#'
 #' # setting `output = "ci"` will return the confidence intervals for unique
 #' # correlation pairs
 #' ggstatsplot::ggcorrmat(
@@ -155,7 +155,7 @@
 #'   p.adjust.method = "BH",
 #'   output = "ci"
 #' )
-#' 
+#'
 #' # modifying elements of the correlation matrix by changing function defaults
 #' ggstatsplot::ggcorrmat(
 #'   data = datasets::iris,
@@ -515,11 +515,13 @@ ggcorrmat <- function(data,
     if (corr.method %in% c("pearson", "spearman", "kendall")) {
       # compute confidence intervals
       ci.mat <- dplyr::full_join(
-        x = tibble::as_tibble(corr_df$ci) %>%
-          tibble::rownames_to_column(., "pair") %>%
-          tibble::rowid_to_column(.),
-        y = tibble::as_tibble(corr_df$ci.adj) %>%
-          tibble::rowid_to_column(.),
+        x = corr_df$ci %>%
+          tibble::rownames_to_column(.data = ., var = "pair") %>%
+          tibble::rowid_to_column(.data = ., var = "rowid") %>%
+          tibble::as_tibble(x = .),
+        y = corr_df$ci.adj %>%
+          tibble::rowid_to_column(.data = ., var = "rowid") %>%
+          tibble::as_tibble(x = .),
         by = "rowid"
       ) %>%
         dplyr::select(.data = ., pair, r, dplyr::everything(), -rowid)
