@@ -91,6 +91,8 @@ gghistostats <- function(data = NULL,
                          bf.prior = 0.707,
                          bf.message = FALSE,
                          robust.estimator = "onestep",
+                         effsize.type = "g",
+                         effsize.noncentral = TRUE,
                          conf.level = 0.95,
                          nboot = 100,
                          k = 2,
@@ -183,6 +185,9 @@ gghistostats <- function(data = NULL,
         test.value = test.value,
         bf.prior = bf.prior,
         robust.estimator = robust.estimator,
+        effsize.type = effsize.type,
+        effsize.noncentral = effsize.noncentral,
+        conf.type = "norm",
         conf.level = conf.level,
         nboot = nboot,
         k = k,
