@@ -1,6 +1,5 @@
 #' @title Grouped histograms for distribution of a numeric variable
 #' @name grouped_gghistostats
-#' @aliases grouped_gghistostats
 #' @description Helper function for `ggstatsplot::gghistostats` to apply this
 #'   function across multiple levels of a given factor and combining the
 #'   resulting plots using `ggstatsplot::combine_plots`.
@@ -14,8 +13,8 @@
 #' @importFrom dplyr group_by n arrange
 #' @importFrom rlang !! enquo quo_name ensym
 #' @importFrom glue glue
-#' @importFrom purrr map set_names
-#' @importFrom tidyr nest
+#' @importFrom purrr pmap
+#' @importFrom tidyr drop_na
 #'
 #' @seealso \code{\link{gghistostats}}
 #'
@@ -56,6 +55,8 @@ grouped_gghistostats <- function(data,
                                  bf.prior = 0.707,
                                  bf.message = FALSE,
                                  robust.estimator = "onestep",
+                                 effsize.type = "g",
+                                 effsize.noncentral = TRUE,
                                  conf.level = 0.95,
                                  nboot = 100,
                                  k = 2,
@@ -150,6 +151,8 @@ grouped_gghistostats <- function(data,
       bf.prior = bf.prior,
       bf.message = bf.message,
       robust.estimator = robust.estimator,
+      effsize.type = effsize.type,
+      effsize.noncentral = effsize.noncentral,
       conf.level = conf.level,
       nboot = nboot,
       low.color = low.color,
@@ -180,7 +183,6 @@ grouped_gghistostats <- function(data,
       ggplot.component = ggplot.component,
       messages = messages
     )
-  #        )
 
   # combining the list of plots into a single plot
   combined_plot <-
