@@ -9,8 +9,8 @@
 #' @param x The grouping variable from the dataframe `data`.
 #' @param y The response (a.k.a. outcome or dependent) variable from the
 #'   dataframe `data`.
-#' @param nboot Number of bootstrap samples for computing effect size (Default:
-#'   `100`).
+#' @param nboot Number of bootstrap samples for computing confidence interval
+#'   for the effect size (Default: `100`).
 #' @param tr Trim level for the mean when carrying out `robust` tests. If you
 #'   get error stating "Standard error cannot be computed because of Winsorized
 #'   variance of 0 (e.g., due to ties). Try to decrease the trimming level.",
@@ -381,7 +381,7 @@ cor_test_ci <- function(data,
     tibble::as_tibble(x = .)
 
   # running correlation and creating a tidy dataframe
-  tidy_df <- broom::tidy(
+  tidy_df <- broomExtra::tidy(
     x = stats::cor.test(
       formula = stats::as.formula(~ x + y),
       data = data,
@@ -405,7 +405,7 @@ cor_test_ci <- function(data,
     d <- data[indices, ]
     # allows boot to select sample
     boot_df <-
-      broom::tidy(
+      broomExtra::tidy(
         stats::cor.test(
           formula = stats::as.formula(~ x + y),
           data = d,
@@ -499,160 +499,6 @@ cor_test_ci <- function(data,
   return(results_df)
 }
 
-
-#' @title Chi-squared test of association with confidence interval for effect
-#'   size (Cramer's *V*).
-#' @name chisq_v_ci
-#' @description Custom function to get confidence intervals for effect size
-#'   measure for chi-squared test of association (Contingency Tables analyses,
-#'   i.e.).
-#'
-#' @param rows The variable to use as the rows in the contingency table.
-#' @param cols the variable to use as the columns in the contingency table.
-#' @inheritParams t1way_ci
-#' @inheritDotParams boot::boot
-#'
-#' @importFrom tibble as_tibble
-#' @importFrom dplyr select
-#' @importFrom rlang !! enquo
-#' @importFrom jmv contTables
-#' @importFrom boot boot
-#' @importFrom boot boot.ci
-#' @importFrom stats na.omit
-#'
-#' @examples
-#' \dontrun{
-#' ggstatsplot:::chisq_v_ci(
-#'   data = ggstatsplot::Titanic_full,
-#'   rows = Sex,
-#'   cols = Survived,
-#'   nboot = 12,
-#'   conf.level = 0.90,
-#'   conf.type = "norm"
-#' )
-#' }
-#'
-#' @keywords internal
-
-# function body
-chisq_v_ci <- function(data,
-                       rows,
-                       cols,
-                       nboot = 100,
-                       conf.level = 0.95,
-                       conf.type = "norm",
-                       ...) {
-
-  # creating a dataframe from entered data
-  data <-
-    dplyr::select(
-      .data = data,
-      rows = !!rlang::enquo(rows),
-      cols = !!rlang::enquo(cols)
-    ) %>%
-    dplyr::filter(.data = ., !is.na(rows), !is.na(cols)) %>%
-    tibble::as_tibble(x = .)
-
-  # results from jamovi
-  jmv_df <- jmv::contTables(
-    data = data,
-    rows = "rows",
-    cols = "cols",
-    phiCra = TRUE
-  )
-
-  # the basic function to get the confidence interval
-  cramer_ci <- function(data,
-                          rows,
-                          cols,
-                          phiCra,
-                          indices) {
-    # allows boot to select sample
-    d <- data[indices, ]
-    # allows boot to select sample
-    boot_df <- jmv::contTables(
-      data = d,
-      rows = "rows",
-      cols = "cols",
-      phiCra = phiCra
-    )
-
-    # return the value of interest: effect size
-    return(as.data.frame(boot_df$nom)$`v[cra]`[[1]])
-  }
-
-  # save the bootstrapped results to an object
-  bootobj <- boot::boot(
-    data = data,
-    statistic = cramer_ci,
-    R = nboot,
-    rows = rows,
-    cols = cols,
-    phiCra = TRUE,
-    parallel = "multicore",
-    ...
-  )
-
-  # get 95% CI from the bootstrapped object
-  bootci <- boot::boot.ci(
-    boot.out = bootobj,
-    conf = conf.level,
-    type = conf.type
-  )
-
-  # extracting ci part
-  if (conf.type == "norm") {
-    ci <- bootci$normal
-  } else if (conf.type == "basic") {
-    ci <- bootci$basic
-  } else if (conf.type == "perc") {
-    ci <- bootci$perc
-  } else if (conf.type == "bca") {
-    ci <- bootci$bca
-  }
-
-  # preparing the dataframe
-  results_df <-
-    tibble::as_tibble(
-      x = cbind.data.frame(
-        "Cramer.V" = as.data.frame(jmv_df$nom)$`v[cra]`[[1]],
-        ci,
-        tibble::as_tibble(as.data.frame(jmv_df$chiSq))
-      )
-    )
-
-  # selecting the columns corresponding to the confidence intervals
-  if (conf.type == "norm") {
-    results_df %<>%
-      dplyr::select(
-        .data = .,
-        chi.sq = `value[chiSq]`,
-        df = `df[chiSq]`,
-        Cramer.V,
-        conf.low = V2,
-        conf.high = V3,
-        p.value = `p[chiSq]`,
-        dplyr::everything()
-      )
-  } else {
-    results_df %<>%
-      dplyr::select(
-        .data = .,
-        chi.sq = `value[chiSq]`,
-        df = `df[chiSq]`,
-        Cramer.V,
-        conf.low = V4,
-        conf.high = V5,
-        p.value = `p[chiSq]`,
-        dplyr::everything()
-      )
-  }
-
-  # return the final dataframe
-  return(results_df)
-}
-
-
 #' @title Robust correlation coefficient and its confidence interval
 #' @name robcor_ci
 #' @description Custom function to get confidence intervals for percentage bend
