@@ -75,7 +75,6 @@ subtitle_t_parametric <- function(data,
                                   k = 2,
                                   ...) {
 
-
   # creating a dataframe
   data <-
     dplyr::select(
@@ -135,7 +134,7 @@ subtitle_t_parametric <- function(data,
   )
 
   stats_df <-
-    broom::tidy(tobject)
+    broomExtra::tidy(tobject)
 
   # effect size object
   effsize_df <-
@@ -185,36 +184,90 @@ subtitle_t_parametric <- function(data,
 #'   (between-subjects designs).
 #' @author Indrajeet Patil, Chuck Powell
 #' @details Two-sample Wilcoxon test, also known as Mann-Whitney test, is
-#'   carried out. The effect size estimate for this test is Spearman's *rho*
-#'   as the ranks of the `y` variable related to the factor `x`.
+#'   carried out.
 #'
 #' @inheritParams subtitle_anova_parametric
 #' @inheritParams subtitle_t_parametric
+#' @inheritParams t1way_ci
 #'
 #' @importFrom dplyr select
-#' @importFrom rlang !! enquo
+#' @importFrom rlang !! enquo exec
 #' @importFrom stats wilcox.test
 #' @importFrom psych corr.test
+#' @importFrom rcompanion wilcoxonR wilcoxonPairedR
 #'
-#' @details For the two independent samples case, the Mann Whitney *U*-test
-#'   is calculated and *W* is reported from *stats::wilcox.test*. For the
-#'   paired samples case the Wilcoxon signed rank test is run and *V* is
-#'   reported.
+#' @details For the two independent samples case, the Mann-Whitney *U*-test is
+#'   calculated and *W* is reported from *stats::wilcox.test*. For the paired
+#'   samples case the Wilcoxon signed rank test is run and *V* is reported.
 #'
 #'   Since there is no single commonly accepted method for reporting effect size
-#'   for these tests we are computing and reporting Spearman's *rho* a.k.a. *r*
-#'   along with the confidence intervals associated with the estimate.
+#'   for these tests we are computing and reporting *r* (computed as
+#'   \eqn{Z/\sqrt{N}}) along with the confidence intervals associated with the
+#'   estimate.
 #'
-#'   We have selected *Spearman's rho* which should be nearly identical to rank
-#'   bi-serial and Somer's *d* for the case of x as two factors (including) as a
-#'   pre/post measure and with *y* treated as ranks rather than raw scores.
+#'   *Note:* The *stats::wilcox.test* function does not follow the
+#'   same convention as *stats::t.test*. The sign of the *V* test statistic
+#'   will always be positive since it is **the sum of the positive signed ranks**.
+#'   Therefore *V* will vary in magnitude but not significance based solely
+#'   on the order of the grouping variable. Consider manually
+#'   reordering your factor levels if appropriate as shown in the second example
+#'   below.
 #'
 #' @examples
-#' subtitle_mann_nonparametric(
+#' \dontrun{
+#' set.seed(123)
+#'
+#' # -------------- between-subjects design ------------------------
+#' # simple function call
+#' ggstatsplot::subtitle_mann_nonparametric(
 #'   data = sleep,
 #'   x = group,
 #'   y = extra
 #' )
+#'
+#' # creating a smaller dataset
+#' msleep_short <- dplyr::filter(
+#'   .data = ggplot2::msleep,
+#'   vore %in% c("carni", "herbi")
+#' )
+#'
+#' # modifying few things
+#' ggstatsplot::subtitle_mann_nonparametric(
+#'   data = msleep_short,
+#'   x = vore,
+#'   y = sleep_rem,
+#'   nboot = 200,
+#'   conf.level = 0.99,
+#'   conf.type = "bca"
+#' )
+#'
+#' # The order of the grouping factor matters when computing *V*
+#' # Changing default alphabeical order manually
+#' msleep_short$vore <- factor(msleep_short$vore,
+#'   levels = c("herbi", "carni")
+#' )
+#'
+#' # note the change in the reported *V* value but the identical
+#' # value for *p* and the reversed effect size
+#' ggstatsplot::subtitle_mann_nonparametric(
+#'   data = msleep_short,
+#'   x = vore,
+#'   y = sleep_rem
+#' )
+#'
+#' # -------------- within-subjects design ------------------------
+#' # using dataset included in the package
+#' ggstatsplot::subtitle_mann_nonparametric(
+#'   data = VR_dilemma,
+#'   x = modality,
+#'   y = score,
+#'   paired = TRUE,
+#'   conf.level = 0.90,
+#'   conf.type = "perc",
+#'   nboot = 200,
+#'   k = 5
+#' )
+#' }
 #' @export
 
 # function body
@@ -224,6 +277,8 @@ subtitle_mann_nonparametric <- function(data,
                                         paired = FALSE,
                                         k = 2,
                                         conf.level = 0.95,
+                                        conf.type = "norm",
+                                        nboot = 100,
                                         messages = TRUE,
                                         ...) {
 
@@ -234,68 +289,78 @@ subtitle_mann_nonparametric <- function(data,
       x = !!rlang::enquo(x),
       y = !!rlang::enquo(y)
     ) %>%
-    tidyr::drop_na(data = .)
+    dplyr::mutate_if(.tbl = ., .predicate = is.character, .funs = as.factor) %>%
+    dplyr::mutate_if(.tbl = ., .predicate = is.factor, .funs = droplevels) %>%
+    tibble::as_tibble(x = .)
 
-  if (!is.numeric(data$y)) {
-    stop("y variable must be numeric")
-  }
+  # properly removing NAs if it's a paired design
+  if (isTRUE(paired) && is.factor(data$x)) {
+    data %<>%
+      long_to_wide_converter(
+        data = .,
+        x = x,
+        y = y
+      ) %>%
+      tidyr::gather(data = ., key, value, -rowid) %>%
+      dplyr::rename(.data = ., x = key, y = value) %>%
+      dplyr::mutate(x = factor(x))
+
+    # sample size
+    sample_size <- length(unique(data$rowid))
+
+    # removing the unnecessary `rowid` column
+    data %<>%
+      dplyr::select(.data = ., -rowid)
+  } else {
+    # remove NAs listwise for between-subjects design
+    data %<>%
+      dplyr::filter(.data = ., !is.na(x), !is.na(y))
 
-  if (is.numeric(data$x)) {
-    # setting up the test and getting its summary
-    stats_df <-
-      broom::tidy(stats::wilcox.test(
-        x = data$x,
-        y = data$y,
-        paired = paired,
-        alternative = "two.sided",
-        na.action = na.omit,
-        exact = FALSE,
-        correct = TRUE,
-        conf.int = TRUE,
-        conf.level = conf.level
-      ))
     # sample size
     sample_size <- nrow(data)
+  }
+
+  # setting up the test and getting its summary
+  stats_df <-
+    broomExtra::tidy(stats::wilcox.test(
+      formula = y ~ x,
+      data = data,
+      paired = paired,
+      alternative = "two.sided",
+      na.action = na.omit,
+      exact = FALSE,
+      correct = TRUE,
+      conf.int = TRUE,
+      conf.level = conf.level
+    ))
+
+  # function to compute effect sizes
+  if (isTRUE(paired)) {
+    .f <- rcompanion::wilcoxonPairedR
   } else {
-    data <-
-      data %>%
-      dplyr::mutate(.data = ., x = droplevels(as.factor(x))) %>%
-      tibble::as_tibble(x = .)
-
-    # setting up the test and getting its summary
-    stats_df <-
-      broom::tidy(stats::wilcox.test(
-        formula = y ~ x,
-        data = data,
-        paired = paired,
-        alternative = "two.sided",
-        na.action = na.omit,
-        exact = FALSE,
-        correct = TRUE,
-        conf.int = TRUE,
-        conf.level = conf.level
-      ))
-    # sample size
-    if (!isTRUE(paired)) {
-      sample_size <- nrow(data)
-    } else {
-      sample_size <- .5 * nrow(data)
-    }
+    .f <- rcompanion::wilcoxonR
   }
 
-  if (is.factor(data$x)) {
-    data$x <- as.integer(data$x)
-  }
-
-  # preparing effect size and ci's
-  effsize_list <- psych::corr.test(
-    x = data$x,
-    y = data$y,
+  # computing effect size
+  effsize_df <- rlang::exec(
+    .fn = .f,
+    x = data$y,
+    g = data$x,
     ci = TRUE,
-    method = "spearman",
-    alpha = 1 - conf.level
-  )
+    conf = conf.level,
+    type = conf.type,
+    R = nboot,
+    histogram = FALSE,
+    digits = k
+  ) %>%
+    tibble::as_tibble(x = .)
 
+  # message about effect size measure
+  if (isTRUE(messages)) {
+    effsize_ci_message(nboot = nboot, conf.level = conf.level)
+  }
+
+  # statistic text
   if (isTRUE(paired)) {
     statistic.text <- quote("log"["e"](italic("V")))
   } else {
@@ -311,10 +376,10 @@ subtitle_mann_nonparametric <- function(data,
     statistic.text = statistic.text,
     statistic = log(stats_df$statistic[[1]]),
     p.value = stats_df$p.value[[1]],
-    effsize.text = quote(italic(r)["Spearman"]),
-    effsize.estimate = effsize_list$r,
-    effsize.LL = effsize_list$ci$lower,
-    effsize.UL = effsize_list$ci$upper,
+    effsize.text = quote(italic(r)),
+    effsize.estimate = effsize_df$r[[1]],
+    effsize.LL = effsize_df$lower.ci[[1]],
+    effsize.UL = effsize_df$upper.ci[[1]],
     n = sample_size,
     conf.level = conf.level,
     k = k
@@ -389,7 +454,6 @@ subtitle_t_robust <- function(data,
                               messages = TRUE,
                               ...) {
 
-
   # creating a dataframe
   data <-
     dplyr::select(
@@ -717,31 +781,50 @@ subtitle_t_bayes <- function(data,
 #' )
 #'
 #' # with defaults
-#' ggstatsplot::effsize_t_parametric(
+#' tobj1 <- t.test(
+#'   formula = sleep_rem ~ vore,
+#'   data = msleep_short
+#' )
+#' ggstatsplot:::effsize_t_parametric(
 #'   formula = sleep_rem ~ vore,
 #'   data = msleep_short,
+#'   tobject = tobj1
 #' )
 #'
 #' # changing defaults
-#' ggstatsplot::effsize_t_parametric(
+#' tobj2 <- t.test(
+#'   formula = sleep_rem ~ vore,
+#'   data = msleep_short,
+#'   mu = 1,
+#'   paired = FALSE,
+#'   conf.level = .99
+#' )
+#' ggstatsplot:::effsize_t_parametric(
 #'   formula = sleep_rem ~ vore,
 #'   data = msleep_short,
 #'   mu = 1, # ignored in this case
 #'   paired = FALSE,
 #'   hedges.correction = TRUE,
 #'   conf.level = .99,
-#'   noncentral = FALSE
+#'   noncentral = FALSE,
+#'   tobject = tobj2
 #' )
 #'
 #' #---------------- one-sample test ------------------------------------
 #'
-#' ggstatsplot::effsize_t_parametric(
+#' tobj3 <- t.test(
+#'   x = msleep_short$sleep_rem,
+#'   mu = 2,
+#'   conf.level = .90
+#' )
+#' ggstatsplot:::effsize_t_parametric(
 #'   formula = ~sleep_rem,
 #'   data = msleep_short,
 #'   mu = 2,
 #'   hedges.correction = TRUE,
 #'   conf.level = .90,
-#'   noncentral = TRUE
+#'   noncentral = TRUE,
+#'   tobject = tobj3
 #' )
 #' }
 #' @keywords internal
@@ -752,8 +835,8 @@ effsize_t_parametric <- function(formula = NULL,
                                  mu = 0,
                                  paired = FALSE,
                                  hedges.correction = TRUE,
-                                 conf.level = NULL,
-                                 var.equal = NULL,
+                                 conf.level = .95,
+                                 var.equal = FALSE,
                                  noncentral = TRUE,
                                  tobject = NULL,
                                  ...) {
@@ -769,6 +852,10 @@ effsize_t_parametric <- function(formula = NULL,
   if (length(formula) == 3 & length(all.vars(formula)) > 2) {
     stop("Your formula has too many variables")
   }
+  if (is.null(tobject)) {
+    stop("This is an internal function and requires a tobject as
+         part of its call")
+  }
 
   # -------------- single sample compare to mu -------------------
 
@@ -783,8 +870,6 @@ effsize_t_parametric <- function(formula = NULL,
     d <- mean.diff / sd.est
     Sigmad <- sqrt((n / (n / 2)^2) + (d^2 / (2 * n)))
     Z <- -stats::qt((1 - conf.level) / 2, df)
-    lower.ci <- c(d - Z * Sigmad)
-    upper.ci <- c(d + Z * Sigmad)
     tvalue <- tobject$statistic
     dfvalue <- tobject$parameter
     civalue <- conf.level
@@ -801,11 +886,6 @@ effsize_t_parametric <- function(formula = NULL,
     group <- eval(formula[[3]], data)
     group <- factor(group)
 
-    #  checking that there are just two levels
-    if (nlevels(group) != 2L) {
-      stop("grouping factor must have exactly 2 levels")
-    }
-
     # test relevant variables
     x <- split(outcome, group)
     y <- x[[2]]
@@ -826,8 +906,6 @@ effsize_t_parametric <- function(formula = NULL,
     d <- mean.diff / sd.est
     Sigmad <- sqrt((n1 + n2) / (n1 * n2) + 0.5 * d^2 / (n1 + n2))
     Z <- -stats::qt((1 - conf.level) / 2, df)
-    lower.ci <- c(d - Z * Sigmad)
-    upper.ci <- c(d + Z * Sigmad)
     method <- "Cohen's d"
     tvalue <- tobject$statistic
     dfvalue <- tobject$parameter
@@ -845,11 +923,6 @@ effsize_t_parametric <- function(formula = NULL,
       outcome <- eval(formula[[2]], data)
       group <- eval(formula[[3]], data)
       group <- droplevels(as.factor(group))
-
-      #  checking that there are just two levels
-      if (nlevels(group) != 2L) {
-        stop("grouping factor must have exactly 2 levels")
-      }
       x <- split(outcome, group)
       y <- x[[2]]
       x <- x[[1]]
@@ -861,24 +934,16 @@ effsize_t_parametric <- function(formula = NULL,
       y <- y[ind]
     }
 
-    # checking if sample sizes are the same across paired samples
-    if (length(x) != length(y)) {
-      stop("paired samples requires samples of the same size")
-    }
-
     # test relevant variables
     n <- length(x)
     df <- n - 1
     r <- cor(x, y)
     sd.est <- sd(x - y)
-    mean.diff <- mean(y) - mean(x)
+    mean.diff <- mean(x) - mean(y)
     d <- mean.diff / sd.est
     Sigmad <- sqrt(((1 / n) + (d^2 / n)) * 2 * (1 - r)) # paired
     Z <- -qt((1 - conf.level) / 2, df)
-    lower.ci <- c(d - Z * Sigmad)
-    upper.ci <- c(d + Z * Sigmad)
     method <- "Cohen's d"
-    diffscores <- as.vector(y - x)
     tvalue <- tobject$statistic
     dfvalue <- tobject$parameter
     civalue <- conf.level
@@ -891,6 +956,10 @@ effsize_t_parametric <- function(formula = NULL,
     method <- "Hedges's g"
     d <- d * (n - 3) / (n - 2.25)
   }
+  lower.ci <- c(d - Z * Sigmad)
+  upper.ci <- c(d + Z * Sigmad)
+
+
 
   # -------------- calculate NCP intervals -------------------
 
@@ -938,13 +1007,13 @@ effsize_t_parametric <- function(formula = NULL,
     return(tibble::tibble(
       method = method,
       estimate = d,
-      conf.low = ncp.lower.ci,
-      conf.high = ncp.upper.ci,
+      conf.low = min(ncp.lower.ci, ncp.upper.ci),
+      conf.high = max(ncp.lower.ci, ncp.upper.ci),
       conf.level = conf.level,
       alternative = "two.sided",
       paired = paired,
       noncentral = noncentral,
-      var.equal = TRUE
+      var.equal = var.equal
     ))
   } else {
     return(tibble::tibble(
@@ -956,7 +1025,7 @@ effsize_t_parametric <- function(formula = NULL,
       alternative = "two.sided",
       paired = paired,
       noncentral = noncentral,
-      var.equal = TRUE
+      var.equal = var.equal
     ))
   }
 }
