@@ -301,6 +301,7 @@ testthat::test_that(
     # tidy dataframe from the function
     tidy_df <- p$plot_env$tidy_df
 
+    # tests
     testthat::expect_identical(p$labels$x, "partial omega-squared")
     testthat::expect_identical(p$labels$y, "term")
     testthat::expect_identical(
@@ -319,13 +320,13 @@ testthat::test_that(
 
     testthat::expect_equal(tidy_df$estimate,
       c(0.30828881, 0.02348073, 0.17365008),
-      tolerance = 1e-3
+      tolerance = 0.001
     )
     testthat::expect_equal(tidy_df$df1[1], 3L)
     testthat::expect_equal(tidy_df$df2[1], 35L)
     testthat::expect_equal(tidy_df$p.value,
-      c(0.000584, 0.163, 0.0148),
-      tolerance = 1e-3
+      c(0.0005838887, 0.1626797382, 0.0148476585),
+      tolerance = 0.001
     )
 
     testthat::expect_identical(
@@ -348,12 +349,12 @@ testthat::test_that(
 
     # checking panel parameters
     testthat::expect_equal(pb$layout$panel_params[[1]]$x.range,
-      c(-0.1754901, 0.7496432),
+      c(-0.1648929, 0.7565467),
       tolerance = 0.001
     )
     testthat::expect_identical(
       pb$layout$panel_params[[1]]$x.labels,
-      c("0.00", "0.25", "0.50")
+      c("0.00", "0.25", "0.50", "0.75")
     )
     testthat::expect_equal(pb$layout$panel_params[[1]]$y.range,
       c(0.4, 3.6),
@@ -633,54 +634,6 @@ testthat::test_that(
   }
 )
 
-# check quantreg output ----------------------------------------------
-
-testthat::test_that(
-  desc = "check quantreg output",
-  code = {
-    testthat::skip_on_cran()
-
-    # set up
-    set.seed(123)
-    library(quantreg)
-    data(stackloss)
-
-    # model
-    mod <-
-      quantreg::rq(
-        formula = stack.loss ~ stack.x,
-        data = stackloss,
-        method = "br"
-      )
-
-    # broom outputs
-    broom_df <-
-      broom::tidy(
-        x = mod,
-        se.type = "iid",
-        conf.int = TRUE,
-        conf.level = 0.90
-      )
-
-    # ggcoefstats outputs
-    tidy_df <- ggstatsplot::ggcoefstats(
-      x = mod,
-      se.type = "iid",
-      exclude.intercept = FALSE,
-      conf.level = 0.90,
-      output = "tidy"
-    )
-
-    # testing
-    testthat::expect_identical(broom_df$term, as.character(tidy_df$term))
-    testthat::expect_equal(broom_df$estimate, tidy_df$estimate, tolerance = 0.001)
-    testthat::expect_equal(broom_df$std.error, tidy_df$std.error, tolerance = 0.001)
-    testthat::expect_equal(broom_df$p.value, tidy_df$p.value, tolerance = 0.001)
-    testthat::expect_equal(broom_df$conf.low, tidy_df$conf.low, tolerance = 0.001)
-    testthat::expect_equal(broom_df$conf.high, tidy_df$conf.high, tolerance = 0.001)
-  }
-)
-
 # check gmm output ----------------------------------------------
 
 testthat::test_that(
@@ -756,10 +709,10 @@ testthat::test_that(
   }
 )
 
-# check clm and polr models (minimal) ----------------------------------------
+# check clm models (minimal) ----------------------------------------
 
 testthat::test_that(
-  desc = "check clm and polr models (minimal)",
+  desc = "check clm models (minimal)",
   code = {
     testthat::skip_on_cran()
 
@@ -781,13 +734,13 @@ testthat::test_that(
     df.clm2 <-
       ggstatsplot::ggcoefstats(
         x = mod.clm,
-        coefficient.type = "alpha",
+        coefficient.type = c("intercept", "alpha"),
         output = "tidy"
       )
     df.clm3 <-
       ggstatsplot::ggcoefstats(
         x = mod.clm,
-        coefficient.type = "beta",
+        coefficient.type = c("location", "beta"),
         output = "tidy"
       )
     df.clm4 <-
@@ -801,70 +754,7 @@ testthat::test_that(
     testthat::expect_equal(dim(df.clm1), c(9L, 12L))
     testthat::expect_equal(dim(df.clm2), c(6L, 12L))
     testthat::expect_equal(dim(df.clm3), c(3L, 12L))
-    testthat::expect_equal(dim(df.clm4), c(3L, 12L))
-
-    # coefficients
-    testthat::expect_identical(
-      unique(df.clm1$coefficient_type),
-      c("alpha", "beta")
-    )
-    testthat::expect_identical(unique(df.clm2$coefficient_type), "alpha")
-    testthat::expect_identical(unique(df.clm3$coefficient_type), "beta")
-    testthat::expect_identical(
-      unique(df.clm4$coefficient_type),
-      unique(df.clm3$coefficient_type)
-    )
-
-    # polr model
-    set.seed(123)
-    library(MASS)
-    mod.polr <- MASS::polr(
-      formula = Sat ~ Infl + Type + Cont,
-      weights = Freq,
-      data = housing
-    )
-
-    # dataframes
-    df.polr1 <-
-      ggstatsplot::ggcoefstats(
-        x = mod.polr,
-        coefficient.type = "both",
-        output = "tidy"
-      )
-    df.polr2 <-
-      ggstatsplot::ggcoefstats(
-        x = mod.polr,
-        coefficient.type = "zeta",
-        output = "tidy"
-      )
-    df.polr3 <-
-      ggstatsplot::ggcoefstats(
-        x = mod.polr,
-        coefficient.type = "coefficient",
-        output = "tidy"
-      )
-    df.polr4 <-
-      ggstatsplot::ggcoefstats(
-        x = mod.polr,
-        coefficient.type = NULL,
-        output = "tidy"
-      )
-
-    # tests
-    testthat::expect_equal(dim(df.polr1), c(8L, 13L))
-    testthat::expect_equal(dim(df.polr2), c(2L, 13L))
-    testthat::expect_equal(dim(df.polr3), c(6L, 13L))
-    testthat::expect_equal(dim(df.polr4), c(6L, 13L))
-    testthat::expect_identical(
-      unique(df.polr1$coefficient_type),
-      c("coefficient", "zeta")
-    )
-    testthat::expect_identical(unique(df.polr2$coefficient_type), "zeta")
-    testthat::expect_identical(unique(df.polr3$coefficient_type), "coefficient")
-    testthat::expect_identical(
-      unique(df.polr4$coefficient_type),
-      unique(df.polr3$coefficient_type)
-    )
+    testthat::expect_equal(dim(df.clm4), c(9L, 12L))
   }
 )
 
@@ -884,12 +774,12 @@ testthat::test_that(
       formula = as.factor(rating) ~ belief * outcome * question
     )
 
-    # selecting alpha terms
+    # selecting intercept terms
     df1 <- broom::tidy(
       x = mod,
       conf.int = TRUE
     ) %>%
-      dplyr::filter(.data = ., coefficient_type == "alpha")
+      dplyr::filter(.data = ., coef.type == "intercept")
 
     # selecting beta terms
     df2 <- broom::tidy(
@@ -897,14 +787,15 @@ testthat::test_that(
       conf.int = TRUE,
       exponentiate = TRUE
     ) %>%
-      dplyr::filter(.data = ., coefficient_type == "beta")
+      dplyr::filter(.data = ., coef.type == "location")
 
     # computed dataframes
     tidy_df1 <-
       ggstatsplot::ggcoefstats(
         x = df1,
         statistic = "z",
-        output = "tidy"
+        output = "tidy",
+        coefficient.type = "intercept"
       )
     tidy_df2 <-
       ggstatsplot::ggcoefstats(
@@ -1044,6 +935,7 @@ testthat::test_that(
     )
     df2 <- dplyr::select(.data = df1, -p.value)
     df3 <- dplyr::select(.data = df1, -statistic)
+    df3$p.value <- as.factor(df3$p.value)
     df4 <- dplyr::select(.data = df1, -df.residual)
     df5 <- tibble::add_column(df1, std.error = c(0.015, 0.2, 0.09))
     df6 <- dplyr::select(.data = df5, -term, -estimate, -std.error)
@@ -1070,7 +962,7 @@ testthat::test_that(
     p3 <- ggstatsplot::ggcoefstats(x = df2, statistic = "t")
     p4 <- ggstatsplot::ggcoefstats(x = df3, statistic = "t") +
       ggplot2::scale_y_discrete(labels = c("x1", "x2", "x3")) +
-      ggplot2::labs(x = "beta", y = NULL)
+      ggplot2::labs(x = "location", y = NULL)
     p5 <- ggstatsplot::ggcoefstats(x = df4, statistic = "t")
     p6 <-
       ggstatsplot::ggcoefstats(
@@ -1162,7 +1054,7 @@ testthat::test_that(
     )
 
     # annotations
-    testthat::expect_identical(p4$labels$x, "beta")
+    testthat::expect_identical(p4$labels$x, "location")
     testthat::expect_null(p4$labels$y, NULL)
     testthat::expect_null(p4$labels$title, NULL)
     testthat::expect_null(p4$labels$subtitle, NULL)
@@ -1433,12 +1325,20 @@ testthat::test_that(
     cfit <- coxph(Surv(time, status) ~ age + sex, lung)
     mod2 <- survfit(cfit)
 
+    # mod-3
+    mod3 <- stats::aov(
+      formula = value ~ attribute * measure + Error(id / (attribute * measure)),
+      data = iris_long
+    )
+
+    # plot
+    p <- ggstatsplot::ggcoefstats(mod3)
+    pb <- ggplot2::ggplot_build(p)
+
     # test failures
-    testthat::expect_error(
-      ggstatsplot::ggcoefstats(x = mod1)
-    )
-    testthat::expect_error(
-      ggstatsplot::ggcoefstats(x = mod2)
-    )
+    testthat::expect_error(ggstatsplot::ggcoefstats(x = mod1))
+    testthat::expect_error(ggstatsplot::ggcoefstats(x = mod2))
+    testthat::expect_null(pb$plot$labels$subtitle, NULL)
+
   }
 )
